@@ -1,16 +1,18 @@
 package UNIVERSAL::can;
+BEGIN {
+  $UNIVERSAL::can::VERSION = '1.20110614';
+}
+# ABSTRACT: work around buggy code calling UNIVERSAL::can() as a function
 
 use strict;
 use warnings;
 
-use vars qw( $VERSION $recursing );
-$VERSION = '1.14';
+use vars qw( $recursing $always_warn );
 
 use Scalar::Util 'blessed';
 use warnings::register;
 
 my $orig;
-use vars '$always_warn';
 
 BEGIN
 {
@@ -40,7 +42,8 @@ sub can
     goto &$orig if $recursing
                 || (   defined $caller
                    &&  defined $_[0]
-                   &&  eval { $caller->isa( $_[0] ); } );
+                   &&  eval { local $recursing = 1;
+                              $caller->isa(blessed $_[0] || $_[0]) } );
 
     # call an overridden can() if it exists
     my $can = eval { $_[0]->$orig('can') || 0 };
@@ -76,11 +79,7 @@ __END__
 
 =head1 NAME
 
-UNIVERSAL::can - Hack around people calling UNIVERSAL::can() as a function
-
-=head1 VERSION
-
-Version 1.14
+UNIVERSAL::can - work around buggy code calling UNIVERSAL::can() as a function
 
 =head1 SYNOPSIS
 
@@ -141,12 +140,16 @@ interface.
 Peter du Marchie van Voorthuysen identified and fixed a problem with calling
 C<SUPER::can>.
 
+Daniel LeWarne found and fixed a deep recursion error.
+
+Norbert Buchmüller fixed an overloading bug in blessed invocants.
+
 The Perl QA list had a huge... discussion... which inspired my realization that
 this module needed to do what it does now.
 
 =head1 COPYRIGHT & LICENSE
 
-Artistic License 2.0, copyright (c) 2005 - 2009 chromatic. Some rights
-reserved.
+Copyright (c) 2005 - 2011, chromatic. This module is made available under the
+same terms as Perl 5.12.
 
 =cut
